
preserve

**************************************************************************************
**************************************************************************************
** Compute amplitudes, durations and rates of expansions and recessions for Figure 1
**************************************************************************************
**************************************************************************************

* setup

local type rcn pk
local treatment a r
local varlist lrgdp rprv

local rrcn r
local rpk x

foreach r of local type {
	foreach t of local treatment {
		foreach v of local varlist {
	
		replace `t'`r`r''_`v'_bb = 100*`t'`r`r''_`v'_bb
		}
	}
}

local treatment a d r
local na Amplitude
local nd Duration
local nr Rate

local p1 "1870-1913"
local p2 "1919-1939"
local p3 "1948-1971"
local p4 "1972-2008"

local c1 year < 1914
local c2 year > 1918 & year < 1940
local c3 year > 1947 & year < 1972
local c4 year > 1971

gen n = _n if _n < 9
gen period =""

* compute

foreach r of local type {
	foreach v of local varlist {

	gen Amplitude=.
	gen Rate=.
	gen Duration=.

		forvalues i=1/4 {

		local z = (`i'*2)-1
	
			foreach t of local treatment {

			sum `t'`r`r''_`v'_bb if `r'_bb==1 & `c`i''

			replace `n`t'' = r(mean) if n==`z'
			replace `n`t'' = -1*r(sd) if n==`z'+1		// make negative for easy formatting in excel
		
			}
			replace period = "`p`i''" if n==`z'
		}
		if "`v'"=="rprv" {
		export excel period Amplitude Rate using ../tables/table2_$today.xlsx, ///
			firstrow(variables) sheet("`r`r''_`v'") sheetreplace
		drop Amplitude Rate Duration
		}
		if "`v'"=="lrgdp" {
		export excel period Amplitude Rate Duration using ../tables/table2_$today.xlsx, ///
			firstrow(variables) sheet("`r`r''_`v'") sheetreplace
		drop Amplitude Rate Duration
		}
	}

}

foreach t of local treatment {
	foreach v of local varlist {

	gen `t'_`v'_bb=.
	replace `t'_`v'_bb=`t'r_`v'_bb if rcn_bb==1
	replace `t'_`v'_bb=`t'x_`v'_bb if pk_bb==1
	}
}

 gen rx=.
	replace rx=2 if rcn_bb==1
	replace rx=1 if pk_bb==1
	
foreach t of local treatment {
	foreach v of local varlist {
		forvalues i= 1/4 {
		
		gen p`i'_`t'_`v'_bb=.
		replace p`i'_`t'_`v'_bb=`t'_`v'_bb if `c`i''
		
		}
	}
}

drop if rx==.

* plot

local trprv "Private Lending per capita"

foreach v of local varlist {

	if "`v'"!="lrgdp" {
	
	graph bar p1_a_`v'_bb p2_a_`v'_bb p3_a_`v'_bb p4_a_`v'_bb, ///
	over(rx, relabel(1 "Expansion" 2 "Recession") label(labsize(small))) ///
	legend(off) ///
	showyvars yvaroptions(relabel(1 "Pre-WWI" 2 "WW1" 3 "BW" 4 "Post-BW") ///
	label(labsize(small))) ///
	ytitle("Percent", size(small)) ylabel(,labsize(small) nogrid) ///
	title("Average Aggregate Amplitude" {stSerif}, size(small)) ///
	graphregion(color(white)) bgcolor(white) ///
	plotregion(color(white)) ///
	blabel(bar, position(ouside) format(%9.1f) color(black) size(small)) ///
	plotregion(style(none)) ///
	name(a`v', replace)
	
	graph bar p1_r_`v'_bb p2_r_`v'_bb p3_r_`v'_bb p4_r_`v'_bb, ///
	over(rx, relabel(1 "Expansion" 2 "Recession") label(labsize(small))) ///
	legend(off) ///
	showyvars yvaroptions(relabel(1 "Pre-WWI" 2 "WW1" 3 "BW" 4 "Post-BW") ///
	label(labsize(small))) ///
	ytitle("Percent" , size(small)) ylabel(,labsize(small) nogrid) ///
	title("Average Aggregate Rate" {stSerif}, size(small)) ///
	graphregion(color(white)) bgcolor(white) ///
	plotregion(color(white)) ///
	blabel(bar, position(ouside) format(%9.1f) color(black) size(small)) ///
	name(r`v', replace)
	
	graph bar p1_d_`v'_bb p2_d_`v'_bb p3_d_`v'_bb p4_d_`v'_bb, ///
	over(rx, relabel(1 "Expansion" 2 "Recession") label(labsize(small))) ///
	legend(off) ///
	showyvars yvaroptions(relabel(1 "Pre-WWI" 2 "WW1" 3 "BW" 4 "Post-BW") ///
	label(labsize(small))) ///
	ytitle("Years", size(small)) ylabel(,labsize(small) nogrid) ///
	title("Average Aggregate Duration", size(small)) ///
	blabel(bar, position(ouside) format(%9.1f) color(black) size(small)) ///
	graphregion(color(white)) plotregion(color(white)) ///
	name(dlrgdp, replace)
	}
	
	else {
	
	graph bar p1_a_`v'_bb p2_a_`v'_bb p3_a_`v'_bb p4_a_`v'_bb, ///
	over(rx, relabel(1 "Expansion" 2 "Recession") label(labsize(small))) ///
	legend(off) ///
	showyvars yvaroptions(relabel(1 "Pre-WWI" 2 "WW1" 3 "BW" 4 "Post-BW") ///
	label(labsize(small))) ///
	ytitle("Percent", size(small)) ylabel( ,labsize(small) nogrid) ///
	title("Average Aggregate Amplitude", size(small)) ///
	graphregion(color(white)) bgcolor(white) ///
	plotregion(color(white)) ///
	blabel(bar, position(ouside) format(%9.1f) color(black) size(small)) ///
	plotregion(style(none)) ///
	name(a`v', replace)
	
	graph bar p1_r_`v'_bb p2_r_`v'_bb p3_r_`v'_bb p4_r_`v'_bb, ///
	over(rx, relabel(1 "Expansion" 2 "Recession") label(labsize(small))) ///
	legend(off) ///
	showyvars yvaroptions(relabel(1 "Pre-WWI" 2 "WW1" 3 "BW" 4 "Post-BW") ///
	label(labsize(small))) ///
	ytitle("Percent", size(small)) ylabel( ,labsize(small) nogrid) ///
	title("Average Aggregate Rate", size(small)) ///
	graphregion(color(white)) bgcolor(white) ///
	plotregion(color(white)) ///
	blabel(bar, position(ouside) format(%9.1f) color(black) size(small)) ///
	name(r`v', replace)
	
	}	
 }


	* blank chart for holes
	twoway scatteri 1 1,               ///
       msymbol(i)                  ///
       ylab("") xlab("")           ///
       ytitle("") xtitle("")       ///
       yscale(off) xscale(off)     ///
       plotregion(lpattern(blank)) ///
       name(blank, replace) scheme(s1color) 


* combine plots

graph combine alrgdp rlrgdp dlrgdp, cols(1) rows(3) ///
	title("Real GDP per capita", size(medsmall)) ///
	graphregion(color(white)) scheme(s1color) ///
	name(gdp, replace)

graph combine arprv rrprv blank, cols(1) rows(3) ///
	title("Real Loans per capita", size(medsmall)) ///
	graphregion(color(white)) scheme(s1color) ///
	name(rprv, replace)
	

graph combine gdp rprv, col(2) scheme(s1color) 
		
graph export ../graphs/fig1_$today.eps, mag(200) orientation(landscape) replace
graph export ../graphs/fig1_$today.pdf, replace //Alan
graph save   ../graphs/fig1_$today.gph, replace //Alan
graph save   ../graphs/figure1.gph, replace //Alan

graph drop _all

restore

