clear
set more off 

local today="`c(current_date)'"
local today=subinstr("`today'"," ","",.)

use "U:\Early\Jorda\JMCB_ee\data\panel14_1_oj"
cd "U:\Early\Jorda\JMCB_ee\August"

drop ccode*
egen ccode = group(iso)
sort ccode year
tsset ccode year, yearly

* Data transformations
gen lrgdp   = log(rgdpbarro)		// real GDP index from Barro
gen lrcon   = log(rconsbarro)		// real consumption index from Barro
gen lmoney  = log(money)			// M2, more or less
gen lstocks = log(stocks)			// Stock indices
gen lnarrow = log(narrowm)			// M1, more or less
gen lcpi    = log(cpi)				// CPI
gen cay		= ca/gdp				// Current Account over GDP ratio
gen lpop    = log(pop)
gen lloans  = log(loans1)

gen rprv  = lloans - lcpi - lpop 	// real per capita private loans

gen riy = iy*rgdpbarro				// real per capita investment
gen lriy = log(riy)

gen rlmoney = lmoney - lcpi

gen dlrgdp  = 100*d.lrgdp			// Annual real per capita GDP growth in percent
gen dlriy	= 100*d.lriy			// Annual real per capita investment growth in percent
gen dlcpi   = 100*d.lcpi			// Annual inflation in percent
gen dlrcon  = 100*d.lrcon			// Annual real consumption growth in percent

gen drprv = d.rprv					// Annual real per capita private loan growth
gen drlmoney= d.rlmoney 			// Annual Growth in M2

replace cay = 100*cay
replace stir = 100*stir
replace ltrate = 100*ltrate 

* Generates NBER peak and trough dummies + recession indicator
qui include ../auxprograms/NBER.do

gen war=0
replace war = 1 if year>=1914 & year<=1919
replace war = 1 if year>=1939 & year<=1947

* Business Cycle Peaks and Troughs using Real GDP (Barro)
* This does Bry and Boschan (1971) on yearly data

qui include ../auxprograms/annual_brybos_loop.do

****** Calculate Cyclical Amplitudes, Durations and Rates *****
* Start with Business Cycles

* manually re-code the AUS 1893-94 event 
* b/c Oscar's stata and Alan's stata disagree ?? 

replace pk_bb=1 if iso=="AUS" & year==1893
replace pk_bb=0 if iso=="AUS" & year==1894
replace pk_bb=0 if iso=="DNK" & year==2007


* New peak do file from Moritz used
qui include ../auxprograms/peak_dummies_August2012.do

replace pk_norm=1 if iso=="AUS" & year==1891

gen pk_comb =  pk_norm + pk_fin + pk_glob
replace pk_bb = 1 if pk_bb==0 & pk_comb==1

local yvars lrgdp rprv /*rpub rtot*/
local cycle bb

include ../auxprograms/amplitude_201204.do

* SRX is the relative amplitude of loan growth to GDP growth during the expansion

gen srx_prv = ax_rprv_bb-ax_lrgdp_bb
replace srx_prv = 100*(ax_rprv_bb-ax_lrgdp_bb)/dx_lrgdp_bb if dx_lrgdp_bb > 0    

local debt prv /*pub tot*/

replace pk_fin = pk_fin + pk_glob

foreach d of local debt {
	gen srx_norm_`d' = srx_`d'*pk_norm
	gen srx_fin_`d'  = srx_`d'*pk_fin 
}

sort ccode year
tsset ccode year, yearly

save private, replace

*******************************************************

drop if war == 1

local p1 f1
local p2 pt2

local c1 year >= 1870
local c2 year > 1946

local type fin norm
local debt prv pub

local rhs drprv dlrgdp dlrcon drlmoney dlcpi dlriy stir ltrate cay ///
		l.drprv l.dlrgdp l.dlrcon l.drlmoney l.dlcpi ///
		l.dlriy l.stir l.ltrate l.cay
		
local irvars lrgdp lriy lcpi lrcon rprv rlmoney cay stir ltrate

forvalues i=1/5 {
	foreach v of local irvars {
	
	if "`v'"=="stir" | "`v'"=="ltrate" | "`v'"=="cay" {
		gen `v'`i' = (f`i'.`v' - `v')
	}
	else {
		gen `v'`i' = 100*(f`i'.`v' - `v')
	}
	}
}

********************************************************************
* Average effects (Unconditional) 

foreach v of local irvars {
	foreach t of local type {
		forvalues j=1/2 {

		gen b1_`v'_`t'_`p`j'' =0
		gen se1_`v'_`t'_`p`j'' =0
		}
	}
}

foreach v of local irvars {
	forvalues i =1/5 {
		forvalues j = 1/2 {
		
		reg `v'`i' pk_norm pk_fin  if `c`j'', noconstant
				
			foreach t of local type {
				
				qui replace b1_`v'_`t'_`p`j'' =  _b[pk_`t'] if _n == `i'+1
				qui replace se1_`v'_`t'_`p`j'' = _se[pk_`t'] if _n == `i'+1
			}
		}
	}
}

********************************************************************
* Responses (conditional)

local varlist2 srx_norm_prv srx_fin_prv
local varlist3 pk_norm pk_fin

foreach v of local irvars {
	forvalues j = 1/2 {
		foreach m of local varlist2 {
			forvalues k = 2/3 {
			
				gen b`k'_1_`m'_`v'_`p`j'' =0
				gen b`k'_10_`m'_`v'_`p`j'' =0
				gen se`k'_`m'_`v'_`p`j'' =0
			}
		}
			foreach n of local varlist3 {
				gen b3_`n'_`v'_`p`j'' =0
				gen se3_`n'_`v'_`p`j'' =0
			}
		}
	}

foreach v of local irvars {
	forvalues i =1/5 {
		forvalues j = 1/2 {
		
				qui xtreg `v'`i' srx_norm_prv srx_fin_prv ///
									`rhs' if `c`j'', fe 
				
				foreach m of local varlist2 {
				
				qui replace b2_1_`m'_`v'_`p`j'' =  _b[`m'] if _n == `i'+1
				qui replace b2_10_`m'_`v'_`p`j'' =  _b[`m'] if _n == `i'+1
				qui replace se2_`m'_`v'_`p`j'' = _se[`m'] if _n == `i'+1
				}
		}
	}
}
			
************************************
foreach v of local irvars {
	forvalues i =1/5 {
		forvalues j = 1/2 {
				
			qui xtreg `v'`i' srx_norm_prv srx_fin_prv ///
								pk_norm pk_fin `rhs' ///
								if `c`j'', fe  
					
				foreach t of local type {	
			
					qui replace b3_pk_`t'_`v'_`p`j'' = _b[pk_`t'] if _n ==`i'+1
					qui replace se3_pk_`t'_`v'_`p`j'' = _se[pk_`t'] if _n ==`i'+1
				}
					
				foreach m of local varlist2 {
			
					qui replace b3_1_`m'_`v'_`p`j'' = _b[`m'] if _n ==`i'+1
					qui replace b3_10_`m'_`v'_`p`j'' = _b[`m'] if _n ==`i'+1
					qui replace se3_`m'_`v'_`p`j'' = _se[`m'] if _n ==`i'+1
				}
		}
	}
}

foreach v of local irvars {
	forvalues j = 1/2 {
		foreach m of local varlist2 {
			
			replace b2_1_`m'_`v'_`p`j'' = 1*b2_1_`m'_`v'_`p`j'' if _n > 1
			replace b2_10_`m'_`v'_`p`j'' = 5*b2_1_`m'_`v'_`p`j'' if _n > 1
		}
		foreach t of local type {
			gen b4_1_srx_`t'_prv_`v'_`p`j'' = b3_pk_`t'_`v'_`p`j'' + 1*b3_1_srx_`t'_prv_`v'_`p`j'' if _n > 1
			gen b4_10_srx_`t'_prv_`v'_`p`j'' = b3_pk_`t'_`v'_`p`j'' + 5*b3_1_srx_`t'_prv_`v'_`p`j'' if _n > 1
		}
	}
}
foreach v of local irvars {
	forvalues j = 1/2 {
		foreach t of local type {
		
		replace b3_1_srx_`t'_prv_`v'_`p`j'' =0
		replace b3_1_srx_`t'_prv_`v'_`p`j'' = b4_1_srx_`t'_prv_`v'_`p`j'' if _n > 1
		replace b3_10_srx_`t'_prv_`v'_`p`j'' =0
		replace b3_10_srx_`t'_prv_`v'_`p`j'' = b4_10_srx_`t'_prv_`v'_`p`j'' if _n > 1
		}
	}
}
**************************************************************

gen Years = _n-1  if _n < 7
gen zero=0

local irvars lrgdp lriy lcpi lrcon rprv rlmoney cay stir ltrate

local tlrgdp "Real GDP per capita"
local tlrcon "Real Consumption per capita"
local tlriy "Real Investment per capita"
local trprv "Real Lending per capita"
local trlmoney "Real M2"
local tlcpi "CPI Prices"
local tstir "Govt. Short-term Interest Rates"
local tltrate "Govt. Long-term Interest Rates"
local tcay "Current Account to GDP Ratio"

local tpf1 "1870-2008"
local tppt2 "1946-2008"

/*
local t2 "Marginal Contribution of Excess Credit in the Expansion to the Cummulative Percent Change" ///
	"from the Start of the Recession" */
local s2 "Experiment: Excess credit at the mean (1% per year) vs. 5%"

local s2f1 "1870-2008"
local s2pt2 "1946-2008"

foreach v of local irvars {
	forvalues j=1/2 {
	
		gen up1_`v'_norm_`p`j'' = b1_`v'_norm_`p`j'' + 1.96*se1_`v'_norm_`p`j''
		gen dn1_`v'_norm_`p`j'' = b1_`v'_norm_`p`j'' - 1.96*se1_`v'_norm_`p`j''
		
		foreach i in 1 10 {
			gen up2_`i'_`v'_norm_`p`j'' = b2_`i'_srx_norm_prv_`v'_`p`j'' + 1.96*se2_srx_norm_prv_`v'_`p`j''
			gen dn2_`i'_`v'_norm_`p`j'' = b2_`i'_srx_norm_prv_`v'_`p`j'' - 1.96*se2_srx_norm_prv_`v'_`p`j''
		}
	}
}

forvalues j=1/2 {
	foreach v of local irvars {

	if "`v'"=="lrgdp" & "`j'"=="1" {
		twoway (rarea up1_`v'_norm_`p`j'' dn1_`v'_norm_`p`j'' Years, ///
				fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line b1_`v'_fin_`p`j'' Years, lcolor(red) lpattern(dash) lwidth(thick)) ///
		(line b1_`v'_norm_`p`j'' Years, lcolor(black) lwidth(thick)) ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		text(-2 5 "Financial crisis", placement(w) color(red)) ///
		text(4 3 "Normal recession", placement(w)) ///
		title(`t`v'', size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		/* ylabel(-12(3)0) */ ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
	}
		if "`v'"=="lrgdp" & "`j'"=="2" {
		twoway (rarea up1_`v'_norm_`p`j'' dn1_`v'_norm_`p`j'' Years, ///
				fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line b1_`v'_fin_`p`j'' Years, lcolor(red) lpattern(dash) lwidth(thick)) ///
		(line b1_`v'_norm_`p`j'' Years, lcolor(black) lwidth(thick)) ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		title(`t`v'', size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		/* ylabel(-12(3)0) */ ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
		}
	if "`v'"=="lcpi" {
		twoway (rarea up1_`v'_norm_`p`j'' dn1_`v'_norm_`p`j'' Years, ///
				fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line b1_`v'_fin_`p`j'' Years, lcolor(red) lpattern(dash) lwidth(thick)) ///
		(line b1_`v'_norm_`p`j'' Years, lcolor(black) lwidth(thick)) ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		title(`t`v'', size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
	}
	if "`v'"=="lriy" {
		twoway (rarea up1_`v'_norm_`p`j'' dn1_`v'_norm_`p`j'' Years, ///
				fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line b1_`v'_fin_`p`j'' Years, lcolor(red) lpattern(dash) lwidth(thick)) ///
		(line b1_`v'_norm_`p`j'' Years, lcolor(black) lwidth(thick)) ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		title(`t`v'', size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		/* ylabel(-4(2)0) */ ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
	}
	}
	graph combine lrgdp`j' lriy`j' lcpi`j', ///
	title(`s2`p`j''', size(small)) ///
	graphregion(color(white)) plotregion(color(white)) ///
	row(1) imargin(tiny) name(g`j', replace)
}

	graph combine g1 g2, ///
	title("Cumulative Percent Change From the Start of the Recession", size(small)) ///
	graphregion(color(white)) plotregion(color(white)) ///
	row(2) ysize(3) xsize(4) imargin(tiny)
		
graph export ../graphs/uncond_av_`today'.eps, mag(110) orientation() replace
graph save ../graphs/uncond_av_`today'.gph, replace

graph drop _all

local irvars1 lrgdp lrcon lriy
local irvars2 rprv rlmoney lcpi
local irvars3 stir ltrate cay 

forvalues j = 1/2 {
	forvalues i=1/3 {
		foreach v of local irvars`i' {
			
		if "`v'"=="lrgdp" & "`j'"=="1" {
		twoway (rarea up2_1_`v'_norm_`p`j'' dn2_1_`v'_norm_`p`j'' Years, ///
		fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line b2_1_srx_norm_prv_`v'_`p`j'' Years, lcolor(black) lwidth(medthick)) ///
		(line b2_10_srx_norm_prv_`v'_`p`j'' Years, lcolor(black) lpattern(dot) lwidth(thick)) ///
		(line b2_1_srx_fin_prv_`v'_`p`j'' Years, lcolor(red) lwidth(medthick)) ///
		(line b2_10_srx_fin_prv_`v'_`p`j'' Years, lcolor(red) lpattern(dash) lwidth(medthick)) ///
		(line zero Years, lcolor(black)), ///
		text(-.8 3.3 "Financial (1%)", placement(w) size(small) color(red)) ///
		text(-2.5 3.8 "Financial (5%)", placement(w) size(small) color(red)) ///
		text(.25 4.25 "Normal (1%)", placement(w) size(small) color(black)) ///
		text(-1 5 "Normal (5%)", placement(w) size(small) color(black)) ///
		title(`t`v'', color(black) size(small)) ytitle("", size(small)) xtitle("", size(small)) ///
		ylabel(, nogrid labsize(vsmall)) xlabel(, labsize(vsmall)) ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`p`j''`i', replace)
		}
		if "`v'"=="lrgdp" & "`j'"=="2" {
		twoway (rarea up2_1_`v'_norm_`p`j'' dn2_1_`v'_norm_`p`j'' Years, ///
		fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line b2_1_srx_norm_prv_`v'_`p`j'' Years, lcolor(black) lwidth(medthick)) ///
		(line b2_10_srx_norm_prv_`v'_`p`j'' Years, lcolor(black) lpattern(dot) lwidth(thick)) ///
		(line b2_1_srx_fin_prv_`v'_`p`j'' Years, lcolor(red) lwidth(medthick)) ///
		(line b2_10_srx_fin_prv_`v'_`p`j'' Years, lcolor(red) lpattern(dash) lwidth(medthick)) ///
		(line zero Years, lcolor(black)), ///
		text(-.75 4.75 "Financial (1%)", placement(w) size(small) color(red)) ///
		text(-2.25 4 "Financial (5%)", placement(w) size(small) color(red)) ///
		text(0.25 4.75 "Normal (1%)", placement(w) size(small) color(black)) ///
		text(-1.35 3 "Normal (5%)", placement(w) size(small) color(black)) ///
		title(`t`v'', color(black) size(small)) ytitle("", size(small)) xtitle("", size(small)) ///
		ylabel(, nogrid labsize(vsmall)) xlabel(, labsize(vsmall)) ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`p`j''`i', replace)
		}
		if "`v'" != "lrgdp" {
		twoway (rarea up2_1_`v'_norm_`p`j'' dn2_1_`v'_norm_`p`j'' Years, ///
		fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line b2_1_srx_norm_prv_`v'_`p`j'' Years, lcolor(black) lwidth(medthick)) ///
		(line b2_10_srx_norm_prv_`v'_`p`j'' Years, lcolor(black) lpattern(dot) lwidth(thick)) ///
		(line b2_1_srx_fin_prv_`v'_`p`j'' Years, lcolor(red) lwidth(medthick)) ///
		(line b2_10_srx_fin_prv_`v'_`p`j'' Years, lcolor(red) lpattern(dash) lwidth(medthick)) ///
		(line zero Years, lcolor(black)), ///
		title(`t`v'', color(black) size(small)) ytitle("", size(small)) xtitle("", size(small)) ///
		ylabel(, nogrid labsize(vsmall)) xlabel(, labsize(vsmall)) ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`p`j''`i', replace)
		}
		
		local glist`p`j''`i' `glist`p`j''`i'' `v'`p`j''`i'
		di "`glist`p`j''`i''"
		
		}
		graph combine `glist`p`j''`i'', ///
		title(, size(medsmall)) ///
		subtitle(, size(medsmall)) ///
		/* ycommon */ ///
		graphregion(color(white)) plotregion(color(white)) ///
		row(1) imargin(tiny) name(`p`j''`i', replace)
		
		local glist`p`j''`i'
		local glist2`p`j'' `glist2`p`j''' `p`j''`i'
		
	}
		
		graph combine `glist2`p`j''', ///
		title("Marginal Contribution of Excess Credit in the Expansion to the Cummulative Percent Change" ///
			"from the Start of the Recession", color(black) size(vsmall)) ///
		subtitle(`s2', size(vsmall)) ///
		t2title(`s2`p`j''', size(vsmall)) ///
		graphregion(color(white)) plotregion(color(white)) ///
		row(3) imargin(tiny) ysize(7) xsize(7) name(`p`j'', replace)
		
		graph export ../graphs/cond_res_2_`p`j''_`today'.eps, mag(110) orientation() replace
		graph save ..graphs/cond_res_2_`p`j''_`today'.gph, replace
		graph drop _all
}
