*** Note the levels - 
*** 	j is used for sample period; there are 2: full sample and post-WWII sample
***			and p is used to label these periods
***		v is used for impuse reponse variables; there are 9
***		t is used for type of recession; there are 2: financial and normal
***		i is used for cummulative change, where i runs from 1 to 5 years forward

*** remove wars
drop if war == 1

*** remove years too close to WWII 
drop if year==1946
drop if year==1947

*** create label names for the two sample periods
local p1 f1
local p2 pt2

*** create the year constraints for the two sample periods
local c1 year >= 1870
local c2 year > 1946

*** the two types of possible recessions
local type fin norm

*** set of RHS controls
local rhs drprv dlrgdp dlrcon drlmoney dlcpi dlriy stir ltrate cay ///
		l.drprv l.dlrgdp l.dlrcon l.drlmoney l.dlcpi ///
		l.dlriy l.stir l.ltrate l.cay

*** IR variables
local irvars lrgdp lriy lcpi lrcon rprv rlmoney cay stir ltrate

*** generage the cummulative changes from 1 year to 5 years forward for each of the IR variables by period
forvalues i=1/5 {
	foreach v of local irvars {
	
	if "`v'"=="stir" | "`v'"=="ltrate" | "`v'"=="cay" {
		gen `v'`i' = (f`i'.`v' - `v')
	}
	else {
		gen `v'`i' = 100*(f`i'.`v' - `v')
	}
	}
}

********************************************************************
* Average effects (Unconditional) 

*** 1. create the beta and se columns to be filled in with the regression results that follow
*** 2. run an average effects regression of cummulative change on each of the IR vars by period
*** 3. fill in the beta and se columns
foreach v of local irvars {
	foreach t of local type {
		forvalues j=1/2 {

		gen b1_`v'_`t'_`p`j'' =0 
		gen se1_`v'_`t'_`p`j'' =0
		}
	}
}

foreach v of local irvars {
	forvalues i =1/5 {
		forvalues j = 1/2 {
		
		reg `v'`i' pk_norm pk_fin if `c`j'', noconstant
				
			foreach t of local type {
				
				qui replace b1_`v'_`t'_`p`j'' =  _b[pk_`t'] if _n == `i'+1
				qui replace se1_`v'_`t'_`p`j'' = _se[pk_`t'] if _n == `i'+1
			}
		}
	}
}

********************************************************************
* Panel with excess credit defined as a rate of real GDP 

local beta pk_norm pk_fin srx_prv

*** generate the coefficient columns to be filled in with the results below
foreach v of local irvars {
	forvalues j=1/2 {
		
		gen b2_lcsd_`v'_`p`j''=0
		gen se2_lcsd_`v'_`p`j''=0
		
		foreach b of local beta { 

			gen b2_`b'_`v'_`p`j'' =0
			gen se2_`b'_`v'_`p`j'' =0

		}
	}
}

*** 1. grab the per-period srx_prv standard deviation 
*** 2. run a panel fixed effects regression of the cummulative change of the impulse response left-hand side variables on 
****** normal and financial recessions and excess crdit with a set of controls 
*** 3. create the linear combination of beta's and se's from normal recessions and excess credit 
****** scaled by it's period sd, store these results as b2_lcsd and se2_lcsd
*** 4. grab the beta's and se's from normal and fiancial recessions and excess credit, store these results as b2_ and se2_

forvalues j = 1/2 {

	sum srx_prv if `c`j'' & srx_prv!=0
	local sd_srx`j' = r(sd)
	
	foreach v of local irvars {
		forvalues i =1/5 {
		
		xtreg `v'`i' pk_norm pk_fin srx_prv `rhs' if `c`j'', fe
		
			lincom pk_fin + (srx_prv*`sd_srx`j'') 
			replace b2_lcsd_`v'_`p`j'' = r(estimate) if _n == `i'+1
			replace se2_lcsd_`v'_`p`j'' = r(se) if _n == `i'+1
		
			foreach b of local beta {
				qui replace b2_`b'_`v'_`p`j'' =  _b[`b'] if _n == `i'+1
				qui replace se2_`b'_`v'_`p`j'' = _se[`b'] if _n == `i'+1
			}
		}
	}
}

*** combine the beta's on financial recessions and excess credit with excess credit scaled 2x it's per-period sd 
foreach v of local irvars {
	forvalues j=1/2 {
	
	gen b3_srx_`v'_`p`j'' = 2*`sd_srx`j''*b2_srx_prv_`v'_`p`j''+ b1_`v'_fin_`p`j''
	}
}
